package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.OrderInfo;
import com.ruoyi.system.domain.dto.OrderInfoDto;

/**
 * 订单信息，若一个订单存在购买多个资源位，则添加多条数据Mapper接口
 * 
 * @author haotian
 * @date 2024-12-17
 */
public interface OrderInfoMapper 
{
    /**
     * 查询订单信息，若一个订单存在购买多个资源位，则添加多条数据
     * 
     * @param orderInfoId 订单信息，若一个订单存在购买多个资源位，则添加多条数据主键
     * @return 订单信息，若一个订单存在购买多个资源位，则添加多条数据
     */
    public OrderInfo selectOrderInfoByOrderInfoId(String orderInfoId);

    /**
     * 查询订单信息，若一个订单存在购买多个资源位，则添加多条数据列表
     * 
     * @param orderInfo 订单信息，若一个订单存在购买多个资源位，则添加多条数据
     * @return 订单信息，若一个订单存在购买多个资源位，则添加多条数据集合
     */
    public List<OrderInfo> selectOrderInfoList(OrderInfo orderInfo);

    /**
     * 新增订单信息，若一个订单存在购买多个资源位，则添加多条数据
     * 
     * @param orderInfo 订单信息，若一个订单存在购买多个资源位，则添加多条数据
     * @return 结果
     */
    public int insertOrderInfo(OrderInfo orderInfo);

    /**
     * 修改订单信息，若一个订单存在购买多个资源位，则添加多条数据
     * 
     * @param orderInfo 订单信息，若一个订单存在购买多个资源位，则添加多条数据
     * @return 结果
     */
    public int updateOrderInfo(OrderInfo orderInfo);

    /**
     * 删除订单信息，若一个订单存在购买多个资源位，则添加多条数据
     * 
     * @param orderInfoId 订单信息，若一个订单存在购买多个资源位，则添加多条数据主键
     * @return 结果
     */
    public int deleteOrderInfoByOrderInfoId(Long orderInfoId);

    /**
     * 批量删除订单信息，若一个订单存在购买多个资源位，则添加多条数据
     * 
     * @param orderInfoIds 需要删除的数据主键集合
     * @return 结果
     */

    public int deleteOrderInfoByOrderInfoIds(Long[] orderInfoIds);


    public List<OrderInfoDto> getOrderInfoDtoList(String orderInfoId);

    public OrderInfoDto getOrderInfoDto(Long id);

    /**
     * 根据orderInfoId返回orderInfo
     * */
    List<Long> getOrderInfoByOrderInfoId(String orderInfoId);

    /***
     * 根据orderInfoId和work_id返回orderInfo
     */
    public OrderInfo getOrderInfoByOrderInfoIdAndWorkId(String orderInfoId, Long workId);
}
