//package com.ruoyi.system.controller;
//
//import java.util.List;
//import javax.servlet.http.HttpServletResponse;
//import org.springframework.security.access.prepost.PreAuthorize;
//import org.springframework.beans.factory.annotation.Autowired;
//import org.springframework.web.bind.annotation.GetMapping;
//import org.springframework.web.bind.annotation.PostMapping;
//import org.springframework.web.bind.annotation.PutMapping;
//import org.springframework.web.bind.annotation.DeleteMapping;
//import org.springframework.web.bind.annotation.PathVariable;
//import org.springframework.web.bind.annotation.RequestBody;
//import org.springframework.web.bind.annotation.RequestMapping;
//import org.springframework.web.bind.annotation.RestController;
//import com.ruoyi.common.annotation.Log;
//import com.ruoyi.common.core.controller.BaseController;
//import com.ruoyi.common.core.domain.AjaxResult;
//import com.ruoyi.common.enums.BusinessType;
//import com.ruoyi.system.domain.OrderInfo;
//import com.ruoyi.system.service.IOrderInfoService;
//import com.ruoyi.common.utils.poi.ExcelUtil;
//import com.ruoyi.common.core.page.TableDataInfo;
//
///**
// * 订单信息，若一个订单存在购买多个资源位，则添加多条数据Controller
// *
// * @author haotian
// * @date 2024-12-17
// */
//@RestController
//@RequestMapping("/system/info")
//public class OrderInfoController extends BaseController
//{
//    @Autowired
//    private IOrderInfoService orderInfoService;
//
//    /**
//     * 查询订单信息，若一个订单存在购买多个资源位，则添加多条数据列表
//     */
//    @PreAuthorize("@ss.hasPermi('system:info:list')")
//    @GetMapping("/list")
//    public TableDataInfo list(OrderInfo orderInfo)
//    {
//        startPage();
//        List<OrderInfo> list = orderInfoService.selectOrderInfoList(orderInfo);
//        return getDataTable(list);
//    }
//
//    /**
//     * 导出订单信息，若一个订单存在购买多个资源位，则添加多条数据列表
//     */
//    @PreAuthorize("@ss.hasPermi('system:info:export')")
//    @Log(title = "订单信息，若一个订单存在购买多个资源位，则添加多条数据", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, OrderInfo orderInfo)
//    {
//        List<OrderInfo> list = orderInfoService.selectOrderInfoList(orderInfo);
//        ExcelUtil<OrderInfo> util = new ExcelUtil<OrderInfo>(OrderInfo.class);
//        util.exportExcel(response, list, "订单信息，若一个订单存在购买多个资源位，则添加多条数据数据");
//    }
//
//    /**
//     * 获取订单信息，若一个订单存在购买多个资源位，则添加多条数据详细信息
//     */
//    @PreAuthorize("@ss.hasPermi('system:info:query')")
//    @GetMapping(value = "/{orderInfoId}")
//    public AjaxResult getInfo(@PathVariable("orderInfoId") Long orderInfoId)
//    {
//        return success(orderInfoService.selectOrderInfoByOrderInfoId(orderInfoId));
//    }
//
//    /**
//     * 新增订单信息，若一个订单存在购买多个资源位，则添加多条数据
//     */
//    @PreAuthorize("@ss.hasPermi('system:info:add')")
//    @Log(title = "订单信息，若一个订单存在购买多个资源位，则添加多条数据", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody OrderInfo orderInfo)
//    {
//        return toAjax(orderInfoService.insertOrderInfo(orderInfo));
//    }
//
//    /**
//     * 修改订单信息，若一个订单存在购买多个资源位，则添加多条数据
//     */
//    @PreAuthorize("@ss.hasPermi('system:info:edit')")
//    @Log(title = "订单信息，若一个订单存在购买多个资源位，则添加多条数据", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@RequestBody OrderInfo orderInfo)
//    {
//        return toAjax(orderInfoService.updateOrderInfo(orderInfo));
//    }
//
//    /**
//     * 删除订单信息，若一个订单存在购买多个资源位，则添加多条数据
//     */
//    @PreAuthorize("@ss.hasPermi('system:info:remove')")
//    @Log(title = "订单信息，若一个订单存在购买多个资源位，则添加多条数据", businessType = BusinessType.DELETE)
//	@DeleteMapping("/{orderInfoIds}")
//    public AjaxResult remove(@PathVariable Long[] orderInfoIds)
//    {
//        return toAjax(orderInfoService.deleteOrderInfoByOrderInfoIds(orderInfoIds));
//    }
//}
